pub struct YcdSeqBlockStream { /* private fields */ }Implementations
Sourceimpl YcdSeqBlockStream
impl YcdSeqBlockStream
pub fn new<P: AsRef<Path>>(file_name: P, unit_size: i32) -> Result<Self>
Sourcepub fn new_from<P: AsRef<Path>>(
file_name: P,
unit_size: i32,
start_position: i64,
) -> Result<Self>
pub fn new_from<P: AsRef<Path>>( file_name: P, unit_size: i32, start_position: i64, ) -> Result<Self>
Open a YCD file and begin sequential reading from an arbitrary 1-based digit position.
start_position is the 1-based absolute digit index at which reading should start.
It must lie within the range covered by this file
(digit_start .. digit_start + digit_length - 1, inclusive).
The unit_size and iteration interface are identical to Self::new.
pub fn has_next(&self) -> bool
pub fn next(&mut self) -> Result<&YcdProcessUnit>