pub struct YcdMultiFileStream { /* private fields */ }Implementations
Sourceimpl YcdMultiFileStream
impl YcdMultiFileStream
pub fn new<P: AsRef<Path>>(file_names: &[P], unit_size: i32) -> Result<Self>
Sourcepub fn new_from<P: AsRef<Path>>(
file_names: &[P],
unit_size: i32,
start_position: i64,
) -> Result<Self>
pub fn new_from<P: AsRef<Path>>( file_names: &[P], unit_size: i32, start_position: i64, ) -> Result<Self>
Open a contiguous list of YCD files and begin sequential reading from an arbitrary 1-based digit position.
start_position is the 1-based absolute digit index at which reading
should start. It must lie within the combined range of all files in
the list. All files in file_names are validated for header
correctness and list continuity before any payload I/O begins.
Files that end before start_position are skipped entirely; only the
file that contains start_position (and all subsequent files) are
opened for streaming.
The unit_size and iteration interface are identical to Self::new.
pub fn has_next(&self) -> bool
pub fn next(&mut self) -> Result<&YcdProcessUnit>